@@ -1072,6 +1072,8 @@ def getAnyPgColormap(name, forceExist=False):
     an arbitrary source. This simply shims access to ``pg.colormap.get`` which tries
     all sources each time a source-specific ``get`` fails.
     :param name: passed to ``pg.colormap.get``
+    :param forceExist: If *True*, the function will raise an error instead of returning
+        *None* if the name was not found.
     """
     for source in None, "matplotlib", "colorcet":
         try:
@@ -1084,7 +1086,7 @@ def getAnyPgColormap(name, forceExist=False):
     # cmap = None at this point
     if forceExist:
         raise ValueError(
-            f"'{colormap}' was not recognized among the available"
+            f"'{name}' was not recognized among the available"
             f" options. Must be one of:\n{fns.listAllPgColormaps()}"
         )
     # else
