@@ -310,7 +310,7 @@ class ActionStack:
         last undo call.
         """
         if not self.canRedo:
-            warn("Nothing to redo", UserWarning)
+            warn("Nothing to redo", UserWarning, stacklevel=2)
             return
 
         self.actions.rotate(-1)
@@ -324,7 +324,7 @@ class ActionStack:
         Undo the last action.
         """
         if not self.canUndo:
-            warn("Nothing to undo", UserWarning)
+            warn("Nothing to undo", UserWarning, stacklevel=2)
             return
 
         with self.ignoreActions(LIB_LOCK):
