@@ -7,4 +7,5 @@ from .plugin import dockPluginFactory, ParamEditorPlugin
 from .. import fns
 
 from .._funcparse import RunOpts
-RunOpts.defaultCfg['title'] = fns.nameFormatter
\ No newline at end of file
+
+RunOpts.defaultCfg["title"] = fns.nameFormatter
