@@ -922,7 +922,9 @@ class EditorPropsMeta(type(QtCore.QObject)):
         oldOpts = cls.__editorPropertyOpts.copy()
         cls.__editorPropertyOpts.update(opts)
         yield
-        cls.__editorPropertyOpts = oldOpts
+        cls.__editorPropertyOpts.update(oldOpts)
+        for newKey in set(cls.__editorPropertyOpts).difference(oldOpts):
+            del cls.__editorPropertyOpts[newKey]
 
 
 class EditorPropsMixin(metaclass=EditorPropsMeta):
