@@ -441,7 +441,7 @@ class AtomicProcess(ProcessStage):
         if wrapWith is not None:
             func = self._wrappedFunc(func, wrapWith)
         self.func = func
-        self.defaultInput = copy.deepcopy(self.input.copy())
+        self.defaultInput = copy.deepcopy(self.input)
 
     @classmethod
     def _wrappedFunc(cls, func, mainResultKeys: StrList):
@@ -529,7 +529,7 @@ class AtomicProcess(ProcessStage):
             else:
                 raise
 
-        if cmp and self.result is not None:
+        if cmp and self.result is not None and not disable:
             # Hypothetically the result should be the same
             return self.result
         if not disable:
